/**
 * Copyright (C) 2009-2012 Couchbase, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 * FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALING
 * IN THE SOFTWARE.
 */

package net.spy.memcached.ops;

import net.spy.memcached.MemcachedNode;
import net.spy.memcached.ObserveResponse;

/**
 * Observe operation.
 */
public interface ObserveOperation extends KeyedOperation {

  /**
   * Get the CAS value advised for this operation.
   */
  long getCasValue();

  /**
   * Get the index advised for this operation.
   */
  int getIndex();

  /**
   * Operation callback for the Observe request.
   */
  interface Callback extends OperationCallback {
    /**
     * Callback for each result from a observe.
     *
     * @param key the key that was retrieved
     * @param cas the CAS value for this record
     * @param or the ObserveResponse
     */
    void gotData(String key, long cas, MemcachedNode node, ObserveResponse or);
  }
}
